LexerTestBuilder

Struct LexerTestBuilder 

pub struct LexerTestBuilder { /* private fields */ }

Implementations

Source

impl LexerTestBuilder

pub fn test_source<S: AsRef<str>>(source: S) -> Self

Create a new test case

pub fn run_test(self)

Start running all the tests. This function will panic if the test failed.

pub fn run_test_with_result(self) -> (Rc<Tree>, String)

Start running all the tests. This function will panic if the test failed. It will return the output of the lexer so it can be used in the Syntax Analysis.

pub fn add_test_s_exp<S: AsRef<str>>(self, s_exp: S) -> Self

Add test to validate the S-Expression.

Example S-Expression:

(raw_file
  (header)
  (comment)
  (token
    ([)
    (token_name)
    (token_arguments
      (:)
      (token_argument_reference)
    )
    (])
  )
  (comment)
  (EOF)
)
pub fn add_test_formatted_source<S: AsRef<str>>( self, formatted_source: S, ) -> Self

Add test to validate the formatting of the source code.

pub fn add_test_lexer_diagnostics(self, diagnostics: Vec<Diagnostic>) -> Self

Add test to validate a full diagnostic message.

pub fn add_test_lexer_diagnostics_codes( self, diagnostics_codes: Vec<&str>, ) -> Self

Add test to validate the diagnostic codes.

Example:

vec!["missing_newline"]
pub fn add_test_lexer_diagnostics_ranges( self, diagnostics_ranges: Vec<Range>, ) -> Self

Add test to validate the diagnostic ranges.

Example:

vec![Range {
    start: Position {
        line: 0,
        character: 0,
    },
    end: Position {
        line: 0,
        character: 17,
    },
}]